@@ -1,4 +1,8 @@
 const CommandType = require('../../utils/CommandType')
+const Command = require("../../utils/Command");
+const ReferenceCache = require('../referenceCache/ReferencesCache')
+const ExceptionSerializer = require('../../utils/exception/ExceptionSerializer')
+
 const ValueHandler = require('./ValueHandler')
 const LoadLibraryHandler = require('./LoadLibraryHandler')
 const GetTypeHandler = require('./GetTypeHandler')
@@ -18,13 +22,10 @@ const ArrayGetSizeHandler = require('./ArrayGetSizeHandler')
 const ArrayGetRankHandler = require('./ArrayGetRankHandler')
 const ArraySetItemHandler = require('./ArraySetItemHandler')
 const ArrayHandler = require('./ArrayHandler')
+const EnableNamespaceHandler = require('./EnableNamespaceHandler')
+const EnableTypeHandler = require('./EnableTypeHandler')
 
 
-const ExceptionSerializer = require('../exception/ExceptionSerializer')
-
-const ReferenceCache = require('./ReferencesCache')
-const Command = require("../../utils/Command");
-
 function isResponseSimpleType(response) {
     let type = typeof (response)
     return ['string', 'boolean', 'number'].includes(type)
@@ -53,13 +54,15 @@ const handlers = {
     [CommandType.ArrayGetSize]: ArrayGetSizeHandler,
     [CommandType.ArrayGetRank]: ArrayGetRankHandler,
     [CommandType.ArraySetItem]: ArraySetItemHandler,
-    [CommandType.Array]: ArrayHandler
+    [CommandType.Array]: ArrayHandler,
+    [CommandType.EnableNamespace]: EnableNamespaceHandler,
+    [CommandType.EnableType]: EnableTypeHandler
 }
 
 class Handler {
     handleCommand(command) {
         try {
-            if (command.commandType == CommandType.RetrieveArray) {
+            if (command.commandType === CommandType.RetrieveArray) {
                 let responseArray = handlers[CommandType.Reference].handleCommand(command.payload[0])
                 return Command.createArrayResponse(responseArray, command.runtimeName)
             }
