@@ -6,5 +6,6 @@ module.exports = {
     Perl: 4,
     Python: 5,
     Ruby: 6,
-    Nodejs: 7
+    Nodejs: 7,
+    Cpp: 8
 }
\ No newline at end of file
