@@ -36,3 +36,5 @@ class CommandType(Enum):
     AsRef = 31
     AsOut = 32
     GetRefValue = 33
+    EnableNamespace = 34
+    EnableType = 35
