@@ -23,7 +23,7 @@ require_relative '../../core/handler/array_handler'
 require_relative '../../core/handler/enable_namespace_handler'
 require_relative '../../core/handler/enable_type_handler'
 require_relative '../../core/reference_cache/references_cache'
-require_relative '../../core/exceptions/exception_serializer'
+require_relative '../../utils/exceptions/exception_serializer'
 
 
 class Handler < AbstractHandler
