@@ -25,6 +25,16 @@ class CommandType
   ARRAY = 23
   RETRIEVE_ARRAY = 24
   SET_INSTANCE_FIELD = 25
+  INVOKE_GENERIC_STATIC_METHOD = 26
+  INVOKE_GENERIC_METHOD = 27
+  GET_ENUM_ITEM = 28
+  GET_ENUM_NAME = 29
+  GET_ENUM_VALUE = 30
+  AS_REF = 31
+  AS_OUT = 32
+  GET_REF_VALUE = 33
+  ENABLE_NAMESPACE = 34
+  ENABLE_TYPE = 35
 
   def self.get_name(command_number)
     case command_number
@@ -80,6 +90,28 @@ class CommandType
       return 'RETRIEVE_ARRAY'
     when 25
       return 'SET_INSTANCE_FIELD'
+    when 26
+      return 'INVOKE_GENERIC_STATIC_METHOD'
+    when 27
+      return 'INVOKE_GENERIC_METHOD'
+    when 28
+      return 'GET_ENUM_ITEM'
+    when 29
+      return 'GET_ENUM_NAME'
+    when 30
+      return 'GET_ENUM_VALUE'
+    when 31
+      return 'AS_REF'
+    when 32
+      return 'AS_OUT'
+    when 33
+      return 'GET_REF_VALUE'
+    when 34
+      return 'ENABLE_NAMESPACE'
+    when 35
+      return 'ENABLE_TYPE'
+    else
+      raise 'Unknown command type'
     end
   end
 end
\ No newline at end of file
