@@ -6,7 +6,7 @@ use Moose;
 use lib 'lib';
 use lib 'data_seed';
 use Nice::Try;
-use aliased 'Javonet::Core::Handler::Exception' => 'Exception';
+use aliased 'Javonet::Core::Exception::Exception' => 'Exception';
 extends 'Javonet::Core::Handler::CommandHandler::AbstractCommandHandler';
 
 sub new {
@@ -33,8 +33,8 @@ sub process {
         my $var = ${class_name};
         return $var;
     }
-    catch ( $e ) {
-        return $e;
+    catch ($e){
+        return Exception->new($e);
     }
 }
 
